IntlMessageExtractionException class

Exception thrown when we cannot process a message properly.

Implemented types

Constructors

IntlMessageExtractionException([String message = ""])
Creates a new exception with an optional error message.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A message describing the error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited