MessageGeneration class

Implementers

Constructors

MessageGeneration()

Properties

allLocales ↔ Set<String>
A list of all the locales for which we have translations. Code that does the reading of translations should add to this.
getter/setter pair
closing → dynamic
Constant string used in generateMainImportFile as the end of the file.
no setter
codegenMode ↔ String
The mode to generate in - either 'release' or 'debug'.
getter/setter pair
extraImports → String
Any additional imports the individual message files need.
no setter
generatedFilePrefix ↔ String
If we have more than one set of messages to generate in a particular directory we may want to prefix some to distinguish them.
getter/setter pair
generatedImportPath ↔ String
If the path to the generated files is something other than the current directory, update the generatedImportPath variable to change the import directives in the generated code.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intlImportPath ↔ String
If the import path following package: is something else, modify the intlImportPath variable to change the import directives in the generated code.
getter/setter pair
jsonMode → bool
no setter
mainPrologue → dynamic
Constant string used in generateMainImportFile for the beginning of the file.
no setter
messagesDeclaration → String
no setter
output ↔ StringBuffer
Holds the generated translations.
getter/setter pair
overrideLookup ↔ String
getter/setter pair
package ↔ String
What is the path to the package for which we are generating.
getter/setter pair
releaseMode → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useDeferredLoading ↔ bool
Should we use deferred loading for the generated libraries.
getter/setter pair

Methods

clearOutput() → void
contentForLocale(String basicLocale, Iterable<TranslatedMessage> translations) → String
Generate a string that containts the dart code with the translations in locale.
generateIndividualMessageFile(String basicLocale, Iterable<TranslatedMessage> translations, String targetDir) → void
Generate a file <generated_file_prefix>messages<locale>.dart for the translations in locale and put it in targetDir.
generateMainImportFile() → String
This section generates the messages_all.dart file based on the list of allLocales.
importForGeneratedFile(String file) → String
Given a base file, return the file prefixed with the path to import it. By default, that is in the current directory, but if generatedImportPath has been set, then use that as a prefix.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prologue(String locale) → String
generateIndividualMessageFile for the beginning of the file, parameterized by locale.
toString() → String
A string representation of this object.
inherited
writeTranslations(Iterable<TranslatedMessage> usableTranslations, String locale) → void
Write out the translated forms.

Operators

operator ==(Object other) → bool
The equality operator.
inherited